@@ -53,7 +53,7 @@ rm -rf usr/include
 rm -rf usr/mkspecs
 rm -rf usr/lib/x86_64-linux-gnu/
 
-# Don't bundle the explorer extentions as we can't do anything with them in the AppImage
+# Don't bundle the explorer extensions as we can't do anything with them in the AppImage
 rm -rf usr/share/caja-python/
 rm -rf usr/share/nautilus-python/
 rm -rf usr/share/nemo-python/
@@ -72,6 +72,7 @@ cp -R /usr/lib/x86_64-linux-gnu/libssl.so* ./usr/lib/
 cp -R /usr/lib/x86_64-linux-gnu/libcrypto.so* ./usr/lib/
 cp -P /usr/local/lib*/libssl.so* ./usr/lib/
 cp -P /usr/local/lib*/libcrypto.so* ./usr/lib/
+cp -P /usr/local/lib*/libsqlite*.so* ./usr/lib/
 
 # NSS fun
 cp -P -r /usr/lib/x86_64-linux-gnu/nss ./usr/lib/
