@@ -81,20 +81,10 @@ public:
      */
     void start(const QString &filePath);
 
-    /**
-     * Computes the checksum for the given device.
-     *
-     * done() is emitted when the calculation finishes.
-     *
-     * The device ownership transfers into the thread that
-     * will compute the checksum. It must not have a parent.
-     */
-    void start(QSharedPointer<QIODevice> device);
-
     /**
      * Computes the checksum synchronously.
      */
-    static QByteArray computeNow(QSharedPointer<QIODevice> device, const QByteArray &checksumType);
+    static QByteArray computeNow(const QString &filePath, const QByteArray &checksumType);
 
     /**
      * Computes the checksum synchronously on file. Convenience wrapper for computeNow().
@@ -108,7 +98,7 @@ private slots:
     void slotCalculationDone();
 
 private:
-    void startImpl(QSharedPointer<QIODevice> device);
+    void startImpl(const QString &filePath);
 
     QByteArray _checksumType;
 
@@ -145,16 +135,6 @@ public:
      */
     void start(const QString &filePath, const QByteArray &checksumHeader);
 
-    /**
-     * Check a device's actual checksum against the provided checksumHeader
-     *
-     * Like the other start() but works on an device.
-     *
-     * The device ownership transfers into the thread that
-     * will compute the checksum. It must not have a parent.
-     */
-    void start(QSharedPointer<QIODevice> device, const QByteArray &checksumHeader);
-
     [[nodiscard]] QByteArray calculatedChecksumType() const;
     [[nodiscard]] QByteArray calculatedChecksum() const;
 
