@@ -207,6 +207,7 @@ struct OCSYNC_EXPORT csync_file_stat_s {
   bool has_ignored_files BITFIELD(1); // Specify that a directory, or child directory contains ignored files.
   bool is_hidden BITFIELD(1); // Not saved in the DB, only used during discovery for local files.
   bool isE2eEncrypted BITFIELD(1);
+  bool is_metadata_missing BITFIELD(1); // Indicates the file has missing metadata, f.ex. the file is not a placeholder in case of vfs.
 
   QByteArray path;
   QByteArray rename_path;
@@ -233,6 +234,7 @@ struct OCSYNC_EXPORT csync_file_stat_s {
     , has_ignored_files(false)
     , is_hidden(false)
     , isE2eEncrypted(false)
+    , is_metadata_missing(false)
   { }
 };
 
