@@ -116,7 +116,7 @@ static time_t FileTimeToUnixTime(FILETIME *filetime, DWORD *remainder)
 std::unique_ptr<csync_file_stat_t> csync_vio_local_readdir(csync_vio_handle_t *handle, OCC::Vfs *vfs) {
 
   std::unique_ptr<csync_file_stat_t> file_stat;
-  DWORD rem;
+  DWORD rem = 0;
 
   errno = 0;
 
@@ -190,14 +190,14 @@ int csync_vio_local_stat(const QString &uri, csync_file_stat_t *buf)
        Possible optimisation: only fetch the file id when we need it (for new files)
       */
 
-    HANDLE h;
+    HANDLE h = nullptr;
     BY_HANDLE_FILE_INFORMATION fileInfo;
     ULARGE_INTEGER FileIndex;
 
     h = CreateFileW(reinterpret_cast<const wchar_t *>(OCC::FileSystem::longWinPath(uri).utf16()), 0, FILE_SHARE_WRITE | FILE_SHARE_READ | FILE_SHARE_DELETE,
-        NULL, OPEN_EXISTING,
+        nullptr, OPEN_EXISTING,
         FILE_ATTRIBUTE_NORMAL | FILE_FLAG_BACKUP_SEMANTICS | FILE_FLAG_OPEN_REPARSE_POINT,
-        NULL);
+        nullptr);
     if( h == INVALID_HANDLE_VALUE ) {
         errno = GetLastError();
         qCCritical(lcCSyncVIOLocal) << "CreateFileW failed on" << uri << OCC::Utility::formatWinError(errno);
@@ -219,7 +219,7 @@ int csync_vio_local_stat(const QString &uri, csync_file_stat_t *buf)
     buf->inode = FileIndex.QuadPart;
     buf->size = (fileInfo.nFileSizeHigh * ((int64_t)(MAXDWORD)+1)) + fileInfo.nFileSizeLow;
 
-    DWORD rem;
+    DWORD rem = 0;
     buf->modtime = FileTimeToUnixTime(&fileInfo.ftLastWriteTime, &rem);
 
     CloseHandle(h);
