@@ -22,17 +22,25 @@ namespace OCC {
 class FileActivityListModel : public ActivityListModel
 {
     Q_OBJECT
+    Q_PROPERTY(QString localPath READ localPath WRITE setLocalPath NOTIFY localPathChanged)
 
 public:
     explicit FileActivityListModel(QObject *parent = nullptr);
 
-public slots:
-    void load(AccountState *accountState, const QString &fileId);
+    [[nodiscard]] QString localPath() const;
 
-protected:
+signals:
+    void localPathChanged();
+
+public slots:
+    void setLocalPath(const QString &localPath);
+    void load();
+
+protected slots:
     void startFetchJob() override;
 
 private:
-    QString _fileId;
+    int _objectId = -1;
+    QString _localPath;
 };
 }
