@@ -568,7 +568,7 @@ void FolderMan::setupLegacyFolder(const QString &fileNamePath, AccountState *acc
             auto legacyBlacklist = folder->journalDb()->getSelectiveSyncList(SyncJournalDb::SelectiveSyncBlackList,
                                                                                    &ok);
             if (!ok) {
-                qCInfo(lcFolderMan) << "There was a problem retriving the database selective sync for " << folder;
+                qCInfo(lcFolderMan) << "There was a problem retrieving the database selective sync for " << folder;
             }
 
             legacyBlacklist << settings.value(QLatin1String("blackList")).toStringList();
@@ -1223,7 +1223,7 @@ Folder *FolderMan::addFolderInternal(
         || _folderMap.contains(folderDefinition.alias)
         || _additionalBlockedFolderAliases.contains(folderDefinition.alias)) {
         // There is already a folder configured with this name and folder names need to be unique
-        folderDefinition.alias = alias + QString::number(++count);
+        folderDefinition.alias = QString::number(alias.toInt() + (++count));
     }
 
     auto folder = new Folder(folderDefinition, accountState, std::move(vfs), this);
@@ -1314,7 +1314,7 @@ QStringList FolderMan::findFileInLocalFolders(const QString &relPath, const Acco
         if (acc && folder->accountState()->account() != acc) {
             continue;
         }
-        if (!serverPath.startsWith(folder->remotePath()))
+        if (!serverPath.startsWith(folder->remotePathTrailingSlash()))
             continue;
 
         QString path = folder->cleanPath() + '/';
@@ -1701,10 +1701,20 @@ static QString checkPathValidityRecursive(const QString &path)
         return FolderMan::tr("The selected path is not a folder!");
     }
 
+    #ifdef Q_OS_WIN
+    if (!selFile.isWritable()) {
+        // isWritable() doesn't cover all NTFS permissions
+        // try creating and removing a test file, and make sure it is excluded from sync
+        if (!Utility::canCreateFileInPath(path)) {
+            return FolderMan::tr("You have no permission to write to the selected folder!");
+        }
+    }
+    #else
     if (!selFile.isWritable()) {
         return FolderMan::tr("You have no permission to write to the selected folder!");
     }
-    return QString();
+    #endif
+    return {};
 }
 
 // QFileInfo::canonicalPath returns an empty string if the file does not exist.
