@@ -104,6 +104,10 @@ public:
     /** Returns the folder which the file or directory stored in path is in */
     Folder *folderForPath(const QString &path);
 
+    // Takes local file paths and finds the corresponding folder, adding to correct selective sync list
+    void whitelistFolderPath(const QString &path);
+    void blacklistFolderPath(const QString &path);
+
     /**
       * returns a list of local files that exist on the local harddisk for an
       * incoming relative server path. The method checks with all existing sync
@@ -115,10 +119,10 @@ public:
     Folder *folder(const QString &);
 
     /**
-     * Migrate accounts from owncloud < 2.0
+     * Migrate accounts from owncloud
      * Creates a folder for a specific configuration, identified by alias.
      */
-    Folder *setupFolderFromOldConfigFile(const QString &, AccountState *account);
+    void setupLegacyFolder(const QString &, AccountState *account);
 
     /**
      * Ensures that a given directory does not contain a sync journal file.
@@ -264,7 +268,7 @@ public slots:
     /**
      * Triggers a sync run once the lock on the given file is removed.
      *
-     * Automatically detemines the folder that's responsible for the file.
+     * Automatically determines the folder that's responsible for the file.
      * See slotWatchedFileUnlocked().
      */
     void slotSyncOnceFileUnlocks(const QString &path);
@@ -354,6 +358,8 @@ private:
 
     [[nodiscard]] bool isSwitchToVfsNeeded(const FolderDefinition &folderDefinition) const;
 
+    void addFolderToSelectiveSyncList(const QString &path, const SyncJournalDb::SelectiveSyncListType list);
+
     QSet<Folder *> _disabledFolders;
     Folder::Map _folderMap;
     QString _folderConfigPath;
