@@ -29,19 +29,6 @@
 
 namespace OCC {
 
-/**
- * @brief The LogWidget class
- * @ingroup gui
- */
-class LogWidget : public QPlainTextEdit
-{
-    Q_OBJECT
-public:
-    explicit LogWidget(QWidget *parent = nullptr);
-
-signals:
-};
-
 /**
  * @brief The LogBrowser class
  * @ingroup gui
@@ -51,31 +38,13 @@ class LogBrowser : public QDialog
     Q_OBJECT
 public:
     explicit LogBrowser(QWidget *parent = nullptr);
-    ~LogBrowser();
-
-    void setLogFile(const QString &, bool);
+    ~LogBrowser() override;
 
 protected:
-    void showEvent(QShowEvent *) override;
     void closeEvent(QCloseEvent *) override;
 
 protected slots:
-    void slotNewLog(const QString &msg);
-    void slotFind();
-    void slotDebugCheckStateChanged(int);
-    void search(const QString &);
-    void slotSave();
-    void slotClearLog();
     void togglePermanentLogging(bool enabled);
-
-private:
-    LogWidget *_logWidget;
-    QLineEdit *_findTermEdit;
-    QCheckBox *_logDebugCheckBox;
-    QCheckBox *_permanentLogging;
-    QPushButton *_saveBtn;
-    QPushButton *_clearBtn;
-    QLabel *_statusLabel;
 };
 
 } // namespace
