@@ -102,6 +102,11 @@ public:
      */
     void setLabel(const QString &shareId, const QString &label);
 
+    /**
+     * Set share hideDownload flag
+     */
+    void setHideDownload(const QString &shareId, const bool hideDownload);
+
     /**
      * Create a new link share
      *
@@ -111,6 +116,8 @@ public:
     void createLinkShare(const QString &path, const QString &name,
         const QString &password);
 
+    void createSecureFileDropLinkShare(const QString &path, const QString &name, const QString &password);
+
     /**
      * Create a new share
      *
