@@ -32,7 +32,6 @@ Q_DECLARE_LOGGING_CATEGORY(lcWizard)
 class WelcomePage;
 class OwncloudSetupPage;
 class OwncloudHttpCredsPage;
-class OwncloudOAuthCredsPage;
 class OwncloudAdvancedSetupPage;
 class OwncloudWizardResultPage;
 class AbstractCredentials;
@@ -76,7 +75,7 @@ public:
 
     /**
      * Shows a dialog explaining the virtual files mode and warning about it
-     * being experimental. Calles the callback with true if enabling was
+     * being experimental. Calls the callback with true if enabling was
      * chosen.
      */
     static void askExperimentalVirtualFilesFeature(QWidget *receiver, const std::function<void(bool enable)> &callback);
@@ -122,7 +121,6 @@ private:
     WelcomePage *_welcomePage;
     OwncloudSetupPage *_setupPage;
     OwncloudHttpCredsPage *_httpCredsPage;
-    OwncloudOAuthCredsPage *_browserCredsPage;
     Flow2AuthCredsPage *_flow2CredsPage;
     OwncloudAdvancedSetupPage *_advancedSetupPage;
     OwncloudWizardResultPage *_resultPage = nullptr;
