@@ -284,6 +284,25 @@ void Account::setPushNotificationsReconnectInterval(int interval)
     _pushNotificationsReconnectTimer.setInterval(interval);
 }
 
+void Account::trySetupClientStatusReporting()
+{
+    if (!_capabilities.isClientStatusReportingEnabled()) {
+        _clientStatusReporting.reset();
+        return;
+    }
+
+    if (!_clientStatusReporting) {
+        _clientStatusReporting = std::make_unique<ClientStatusReporting>(this);
+    }
+}
+
+void Account::reportClientStatus(const ClientStatusReportingStatus status) const
+{
+    if (_clientStatusReporting) {
+        _clientStatusReporting->reportClientStatus(status);
+    }
+}
+
 void Account::trySetupPushNotifications()
 {
     // Stop the timer to prevent parallel setup attempts
@@ -464,7 +483,7 @@ QSslConfiguration Account::getOrCreateSslConfig()
     //  "An internal error number 1060 happened. SSL handshake failed, client certificate was requested: SSL error: sslv3 alert handshake failure"
     QSslConfiguration sslConfig = QSslConfiguration::defaultConfiguration();
 
-    // Try hard to re-use session for different requests
+    // Try hard to reuse session for different requests
     sslConfig.setSslOption(QSsl::SslOptionDisableSessionTickets, false);
     sslConfig.setSslOption(QSsl::SslOptionDisableSessionSharing, false);
     sslConfig.setSslOption(QSsl::SslOptionDisableSessionPersistence, false);
@@ -669,6 +688,8 @@ void Account::setCapabilities(const QVariantMap &caps)
 
     setupUserStatusConnector();
     trySetupPushNotifications();
+
+    trySetupClientStatusReporting();
 }
 
 void Account::setupUserStatusConnector()
