@@ -89,6 +89,9 @@ Logger::Logger(QObject *parent)
 
 Logger::~Logger()
 {
+    if (_logstream) {
+        _logstream->flush();
+    }
 #ifndef NO_MSG_HANDLER
     qInstallMessageHandler(nullptr);
 #endif
@@ -100,11 +103,6 @@ void Logger::postGuiLog(const QString &title, const QString &message)
     emit guiLog(title, message);
 }
 
-void Logger::postOptionalGuiLog(const QString &title, const QString &message)
-{
-    emit optionalGuiLog(title, message);
-}
-
 void Logger::postGuiMessage(const QString &title, const QString &message)
 {
     emit guiMessage(title, message);
@@ -149,6 +147,9 @@ void Logger::doLog(QtMsgType type, const QMessageLogContext &ctx, const QString
 
         if (linesCounter >= MaxLogLinesCount) {
             linesCounter = 0;
+            if (_logstream) {
+                _logstream->flush();
+            }
             closeNoLock();
             enterNextLogFileNoLock();
         }
@@ -158,7 +159,7 @@ void Logger::doLog(QtMsgType type, const QMessageLogContext &ctx, const QString
         _crashLog[_crashLogIndex] = msg;
 
         if (_logstream) {
-            (*_logstream) << msg << Qt::endl;
+            (*_logstream) << msg << "\n";
             if (_doFileFlush)
                 _logstream->flush();
         }
@@ -288,8 +289,9 @@ void Logger::enterNextLogFileNoLock()
         }
 
         // Tentative new log name, will be adjusted if one like this already exists
-        QDateTime now = QDateTime::currentDateTime();
-        QString newLogName = now.toString("yyyyMMdd_HHmm") + "_nextcloud.log";
+        const auto now = QDateTime::currentDateTime();
+        const auto cLocale = QLocale::c(); // Some system locales generate strings that are incompatible with filesystem
+        QString newLogName = cLocale.toString(now, QStringLiteral("yyyyMMdd_HHmm")) + QStringLiteral("_nextcloud.log");
 
         // Expire old log files and deal with conflicts
         QStringList files = dir.entryList(QStringList("*owncloud.log.*"), QDir::Files, QDir::Name) +
