@@ -836,7 +836,7 @@ bool AvatarJob::finished()
             }
         }
     }
-    emit(avatarPixmap(avImage));
+    emit avatarPixmap(avImage);
     return true;
 }
 #endif
