@@ -101,6 +101,7 @@ bool Progress::isWarningKind(SyncFileItem::Status kind)
         || kind == SyncFileItem::Conflict || kind == SyncFileItem::Restoration
         || kind == SyncFileItem::DetailError || kind == SyncFileItem::BlacklistedError
         || kind == SyncFileItem::FileLocked || kind == SyncFileItem::FileNameInvalid
+        || kind == SyncFileItem::FileNameInvalidOnServer
         || kind == SyncFileItem::FileNameClash;
 }
 
@@ -284,8 +285,8 @@ ProgressInfo::Estimates ProgressInfo::totalProgress() const
     // on the upload speed. That's particularly relevant for large file
     // up/downloads, where files per second will be close to 0.
     //
-    // However, when many *small* files are transfered, the estimate
-    // can become very pessimistic as the transfered amount per second
+    // However, when many *small* files are transferred, the estimate
+    // can become very pessimistic as the transferred amount per second
     // drops significantly.
     //
     // So, if we detect a high rate of files per second or a very low
@@ -323,7 +324,7 @@ quint64 ProgressInfo::optimisticEta() const
 {
     // This assumes files and transfers finish as quickly as possible
     // *but* note that maxPerSecond could be serious underestimate
-    // (if we never got to fully excercise transfer or files/second)
+    // (if we never got to fully exercise transfer or files/second)
 
     return _fileProgress.remaining() / _maxFilesPerSecond * 1000
         + _sizeProgress.remaining() / _maxBytesPerSecond * 1000;
