@@ -73,7 +73,9 @@ void PropagateDownloadEncrypted::checkFolderEncryptedMetadata(const QJsonDocumen
   qCDebug(lcPropagateDownloadEncrypted) << "Metadata Received reading"
                                         << _item->_instruction << _item->_file << _item->_encryptedFileName;
   const QString filename = _info.fileName();
-  const FolderMetadata metadata(_propagator->account(), json.toJson(QJsonDocument::Compact));
+  const FolderMetadata metadata(_propagator->account(),
+                                _item->_e2eEncryptionStatus == SyncFileItem::EncryptionStatus::EncryptedMigratedV1_2 ? FolderMetadata::RequiredMetadataVersion::Version1_2 : FolderMetadata::RequiredMetadataVersion::Version1,
+                                json.toJson(QJsonDocument::Compact));
   if (metadata.isMetadataSetup()) {
       const QVector<EncryptedFile> files = metadata.files();
 
