@@ -178,7 +178,7 @@ signals:
     void started();
 
     /**
-     * Emited when the sync engine detects that all the files have been removed or change.
+     * Emitted when the sync engine detects that all the files have been removed or change.
      * This usually happen when the server was reset or something.
      * Set *cancel to true in a slot connected from this signal to abort the sync.
      */
@@ -187,6 +187,8 @@ signals:
     // A new folder was discovered and was not synced because of the confirmation feature
     void newBigFolder(const QString &folder, bool isExternal);
 
+    void existingFolderNowBig(const QString &folder);
+
     /** Emitted when propagation has problems with a locked file.
      *
      * Forwarded from OwncloudPropagator::seenLockedFile.
@@ -210,8 +212,8 @@ private slots:
 
     void slotItemCompleted(const OCC::SyncFileItemPtr &item, const OCC::ErrorCategory category);
     void slotDiscoveryFinished();
-    void slotPropagationFinished(bool success);
-    void slotProgress(const OCC::SyncFileItem &item, qint64 curent);
+    void slotPropagationFinished(SyncFileItem::Status status);
+    void slotProgress(const OCC::SyncFileItem &item, qint64 current);
     void slotCleanPollsJobAborted(const QString &error, const OCC::ErrorCategory category);
 
     /** Records that a file was touched by a job. */
@@ -291,6 +293,8 @@ private:
     // cleanup and emit the finished signal
     void finalize(bool success);
 
+    void processCaseClashConflictsBeforeDiscovery();
+
     // Aggregate scheduled sync runs into interval buckets. Can be used to
     // schedule a sync run per bucket instead of per file, reducing load.
     //
@@ -311,7 +315,7 @@ private:
 
     static bool s_anySyncRunning; //true when one sync is running somewhere (for debugging)
 
-    // Must only be acessed during update and reconcile
+    // Must only be accessed during update and reconcile
     QVector<SyncFileItemPtr> _syncItems;
 
     AccountPtr _account;
