@@ -336,6 +336,11 @@ public:
      */
     [[nodiscard]] QString gitSHA1() const;
 
+    /**
+     * About info text
+     */
+    [[nodiscard]] QString aboutInfo() const;
+
     /**
      * About dialog contents
      */
