@@ -86,8 +86,7 @@ using namespace OCC::Utility;
         QFileInfo fi(file);
         QVERIFY(fi.exists());
 
-        auto sharedFile(QSharedPointer<QFile>::create(file));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumMD5C);
+        ChecksumCalculator checksumCalculator(file, OCC::checkSumMD5C);
 
         const auto sum = checksumCalculator.calculate();
 
@@ -106,8 +105,7 @@ using namespace OCC::Utility;
         QFileInfo fi(file);
         QVERIFY(fi.exists());
 
-        auto sharedFile(QSharedPointer<QFile>::create(file));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumSHA1C);
+        ChecksumCalculator checksumCalculator(file, OCC::checkSumSHA1C);
 
         const auto sum = checksumCalculator.calculate();
 
@@ -129,8 +127,7 @@ using namespace OCC::Utility;
 
         connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
-        auto sharedFile(QSharedPointer<QFile>::create(_testfile));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumAdlerC);
+        ChecksumCalculator checksumCalculator(_testfile, OCC::checkSumAdlerC);
 
         _expected = checksumCalculator.calculate();
 
@@ -152,8 +149,7 @@ using namespace OCC::Utility;
         vali->setChecksumType(_expectedType);
         connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
-        auto sharedFile(QSharedPointer<QFile>::create(_testfile));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumMD5C);
+        ChecksumCalculator checksumCalculator(_testfile, OCC::checkSumMD5C);
 
         _expected = checksumCalculator.calculate();
         vali->start(_testfile);
@@ -172,8 +168,7 @@ using namespace OCC::Utility;
         vali->setChecksumType(_expectedType);
         connect(vali, &ComputeChecksum::done, this, &TestChecksumValidator::slotUpValidated);
 
-        auto sharedFile(QSharedPointer<QFile>::create(_testfile));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumSHA1C);
+        ChecksumCalculator checksumCalculator(_testfile, OCC::checkSumSHA1C);
         _expected = checksumCalculator.calculate();
 
         vali->start(_testfile);
@@ -193,16 +188,13 @@ using namespace OCC::Utility;
         connect(vali, &ValidateChecksumHeader::validated, this, &TestChecksumValidator::slotDownValidated);
         connect(vali, &ValidateChecksumHeader::validationFailed, this, &TestChecksumValidator::slotDownError);
 
-        auto sharedFile(QSharedPointer<QFile>::create(_testfile));
-        ChecksumCalculator checksumCalculator(sharedFile, OCC::checkSumAdlerC);
+        ChecksumCalculator checksumCalculator(_testfile, OCC::checkSumAdlerC);
         _expected = checksumCalculator.calculate();
 
         QByteArray adler = checkSumAdlerC;
         adler.append(":");
         adler.append(_expected);
 
-        sharedFile->open(QIODevice::ReadOnly);
-        sharedFile->seek(0);
         _successDown = false;
         vali->start(_testfile, adler);
 
@@ -211,14 +203,12 @@ using namespace OCC::Utility;
         _expectedError = QStringLiteral("The downloaded file does not match the checksum, it will be resumed. \"543345\" != \"%1\"").arg(QString::fromUtf8(_expected));
         _expectedFailureReason = ValidateChecksumHeader::FailureReason::ChecksumMismatch;
         _errorSeen = false;
-        sharedFile->seek(0);
         vali->start(_testfile, "Adler32:543345");
         QTRY_VERIFY(_errorSeen);
 
         _expectedError = QLatin1String("The checksum header contained an unknown checksum type \"Klaas32\"");
         _expectedFailureReason = ValidateChecksumHeader::FailureReason::ChecksumTypeUnknown;
         _errorSeen = false;
-        sharedFile->seek(0);
         vali->start(_testfile, "Klaas32:543345");
         QTRY_VERIFY(_errorSeen);
 
