@@ -14,7 +14,7 @@ using namespace OCC;
 
 static constexpr qint64 stopAfter = 3'123'668;
 
-/* A FakeGetReply that sends max 'fakeSize' bytes, but whose ContentLength has the corect size */
+/* A FakeGetReply that sends max 'fakeSize' bytes, but whose ContentLength has the correct size */
 class BrokenFakeGetReply : public FakeGetReply
 {
     Q_OBJECT
@@ -26,7 +26,7 @@ public:
     {
         if (aborted)
             return 0;
-        return std::min(size, fakeSize) + QIODevice::bytesAvailable(); // NOLINT: This is intended to simulare the brokeness
+        return std::min(size, fakeSize) + QIODevice::bytesAvailable(); // NOLINT: This is intended to simulate the brokenness
     }
 
     qint64 readData(char *data, qint64 maxlen) override
@@ -61,7 +61,7 @@ private slots:
     {
         FakeFolder fakeFolder{ FileInfo::A12_B12_C12_S12() };
         fakeFolder.syncEngine().setIgnoreHiddenFiles(true);
-        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &SyncEngine::itemCompleted);
+        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &OCC::SyncEngine::itemCompleted);
         auto size = 30 * 1000 * 1000;
         fakeFolder.remoteModifier().insert("A/a0", size);
 
@@ -96,7 +96,7 @@ private slots:
 
         FakeFolder fakeFolder{FileInfo::A12_B12_C12_S12()};
         fakeFolder.syncEngine().setIgnoreHiddenFiles(true);
-        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &SyncEngine::itemCompleted);
+        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &OCC::SyncEngine::itemCompleted);
         auto size = 3'500'000;
         fakeFolder.remoteModifier().insert("A/broken", size);
 
@@ -236,7 +236,7 @@ private slots:
         resendActual = 0;
         resendExpected = 10;
 
-        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &SyncEngine::itemCompleted);
+        QSignalSpy completeSpy(&fakeFolder.syncEngine(), &OCC::SyncEngine::itemCompleted);
         QVERIFY(!fakeFolder.syncOnce());
         QCOMPARE(resendActual, 4); // the 4th fails because it only resends 3 times
         QCOMPARE(getItem(completeSpy, "A/resendme")->_status, SyncFileItem::NormalError);
