@@ -153,7 +153,7 @@ private slots:
         QVERIFY(!record._valid);
 
         record._errorCount = 5;
-        record._chunk = 12;
+        record._chunkUploadV1 = 12;
         record._transferid = 812974891;
         record._size = 12894789147;
         record._modtime = dropMsecs(QDateTime::currentDateTime());
